import { Coordinate } from '../utils/coordinate';
export declare class MapElement {
    /**
     * A flag indicating if this `MapElement` is currently active.  The active
     * element is styled differently to make it stand out.
     */
    active: boolean;
    /**
     * A flag indicating if this `MapElement` is currently enabled.  An element
     * that is not enabled is not rendered on the Map.
     */
    enabled: boolean;
    /**
     * The identifier for this `MapElement`.
     */
    id: number;
    /**
     * The name of this `MapElement`.
     */
    name: string;
    /**
     * The array of `Coordinate`s that are used to draw this `MapElement`.
     */
    _coordinates: Coordinate[];
    icons: {
        src: string;
        width?: number;
        height?: number;
    }[];
    scale: number;
    /**
     * Create a new `MapElement`.
     * @param id A value to set as the ID of the `MapElement`.
     */
    constructor(id?: number);
    /**
     * Move this `MapElement` by a specified amount.
     * @param delta The amount to move
     */
    move(delta: Coordinate): void;
}
