import '../stencil.core';
import { Coordinate } from '../utils/coordinate';
import { MapElement } from './map-element';
export declare class MapRegion extends MapElement {
    open: boolean;
    path: string;
    coordinates: Coordinate[];
    /**
     * Renders the `MapRegion`.
     */
    render(): JSX.Element | undefined;
    /**
     * Generates the DOM necessary to display the control points for this
     * `MapElement`.  There are control points at the median and endpoint of each
     * edge.  This allows any point of the `MapElement` to be moved as well as new
     * point created on each line.
     */
    renderControls(): JSX.Element;
    /**
     * Add a new point to the array of points that represent this `MapRegion`.
     * @param c The `Coordinate` representing the point to add
     * @param index The index where the point should be added.  If not specified,
     * adds the point at the end
     */
    addPoint(c: Coordinate, index?: number): void;
    /**
     * Remove a point from the array of points that represent this `MapRegion`.
     * If no index is specified, the last point is removed.
     * @param index The index of the point to remove
     */
    removePoint(index?: number): void;
    /**
     * Move this `MapRegion` by a specified offset.
     * @param delta The amount to move by
     */
    move(delta: Coordinate): void;
    /**
     * Move a single point of this `MapRegion` by a specified amount.
     * @param delta The amount to move by
     * @param index The index of the point to move
     */
    movePoint(delta: Coordinate, index: number): void;
}
